import { TSClone, TSObject } from "./tsobject";
import { Comparison, Nullable } from "./types";
export interface TSURLParseOptions {
    acceptedProtocols?: Nullable<string[]>;
    refusesParameters?: Nullable<boolean>;
    throwsError?: Nullable<boolean>;
}
export declare class TSURL implements TSObject, TSClone<TSURL> {
    static HostMaxLength: number;
    static AutoEscapeChars: string[];
    static StandardURLProtocols: Set<string>;
    static AutoEscapeCharSet: Set<string>;
    static EndhostCharSet: Set<string>;
    private _auth;
    private _hash;
    private _hostname;
    private _pathname;
    private _port;
    private _protocol;
    private _search;
    private _w3cProtocol;
    private _ipv6;
    readonly searchParams: URLSearchParams;
    static from(source: URL, options?: Nullable<TSURLParseOptions>): TSURL | null;
    static url(source: Nullable<string>, opts?: TSURLParseOptions): TSURL | null;
    private constructor();
    get w3c(): boolean;
    get origin(): string;
    get host(): string;
    get href(): string;
    get auth(): string;
    get hash(): string;
    get search(): string;
    get pathname(): string;
    get hostname(): string;
    set hostname(h: string);
    get port(): string;
    set port(p: string);
    get protocol(): string;
    set protocol(s: string);
    isValid(opts?: TSURLParseOptions): boolean;
    isEqual(other: any): boolean;
    compare(other: any): Comparison;
    toString(): string;
    toJSON: () => string;
    toArray(): string[];
    clone(): TSURL;
}
